@@ -496,6 +496,8 @@ static void PrintVal(Val *val) {
 	    }
 	}
 	putchar( ']' );
+    } else if ( val->type==v_tag ) {
+	printf( "'%c%c%c%c'", val->u.ival>>24, (val->u.ival>>16)&0xff, (val->u.ival>>8)&0xff, val->u.ival&0xff );
     } else if ( val->type==v_int )
 	printf( "%d", val->u.ival );
     else if ( val->type==v_unicode )
@@ -2041,8 +2043,8 @@ static void comp(Context *c,Val *val) {
 	    if ( val->type==v_str && other.type==v_str ) {
 		cmp = strcmp(val->u.sval,other.u.sval);
 		free(val->u.sval); free(other.u.sval);
-	    } else if (( val->type==v_int || val->type==v_unicode ) &&
-		    (other.type==v_int || other.type==v_unicode)) {
+	    } else if (( val->type==v_int || val->type==v_unicode || val->type==v_tag) &&
+		    (other.type==v_int || other.type==v_unicode || other.type==v_tag)) {
 		cmp = val->u.ival - other.u.ival;
 	    } else 
 		error( c, "Invalid type in integer expression" );
